==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/sl-SI/admin/locations/table.php <==
<?php

return [
    'about_locations_title'     => 'O lokacijah',
    'about_locations'           => 'Lokacije se uporabljajo za sledenje informacij o lokaciji uporabnika, sredstva in drugih elementov',
    'assets_rtd'                => 'Sredstva', // This has NEVER meant Assets Retired. I don't know how it keeps getting reverted.
    'assets_checkedout'         => 'Sredstva dodeljena',
    'id'                        => 'ID',
    'city'                      => 'Mesto',
    'state'                     => 'Država',
    'country'                   => 'Država',
    'create'                    => 'Ustvari lokacijo',
    'update'                    => 'Posodobi lokacijo',
    'print_assigned'            => 'Natisni dodeljene',
    'print_all_assigned'        => 'Natisni vse dodeljene',
    'name'                      => 'Ime lokacije',
    'address'                   => 'Naslov',
    'address2'                   => 'Address Line 2',
    'zip'                       => 'Poštna številka',
    'locations'                 => 'Lokacije',
    'parent'                    => 'Starš',
    'currency'                  => 'Lokalna valuta',
    'ldap_ou'                   => 'LDAP Search OU',
    'user_name'                 => 'User Name',
    'department'                => 'Oddelek',
    'location'                  => 'Lokacija',
    'asset_tag'                 => 'Assets Tag',
    'asset_name'                => 'Ime',
    'asset_category'            => 'Kategorija',
    'asset_manufacturer'        => 'Proizvajalec',
    'asset_model'               => 'Model',
    'asset_serial'              => 'Serijska številka',
    'asset_location'            => 'Lokacija',
    'asset_checked_out'         => 'Izdano',
    'asset_expected_checkin'    => 'Expected Checkin',
    'date'                      => 'Datum:',
    'phone'                     => 'Location Phone',
    'signed_by_asset_auditor'   => 'Signed By (Asset Auditor):',
    'signed_by_finance_auditor' => 'Signed By (Finance Auditor):',
    'signed_by_location_manager' => 'Signed By (Location Manager):',
    'signed_by'                 => 'Signed Off By:',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/sl-SI/admin/locations/table.php <==
<?php

return [
    'about_locations_title'     => 'O lokacijah',
    'about_locations'           => 'Lokacije se uporabljajo za sledenje informacij o lokaciji uporabnika, sredstva in drugih elementov',
    'assets_rtd'                => 'Sredstva', // This has NEVER meant Assets Retired. I don't know how it keeps getting reverted.
    'assets_checkedout'         => 'Sredstva dodeljena',
    'id'                        => 'ID',
    'city'                      => 'Mesto',
    'state'                     => 'Država',
    'country'                   => 'Država',
    'create'                    => 'Ustvari lokacijo',
    'update'                    => 'Posodobi lokacijo',
    'print_assigned'            => 'Natisni dodeljene',
    'print_all_assigned'        => 'Natisni vse dodeljene',
    'name'                      => 'Ime lokacije',
    'address'                   => 'Naslov',
    'address2'                   => 'Druga vrstica naslova',
    'zip'                       => 'Poštna številka',
    'locations'                 => 'Lokacije',
    'parent'                    => 'Starš',
    'currency'                  => 'Lokalna valuta',
    'ldap_ou'                   => 'LDAP Search OU',
    'user_name'                 => 'Uporabniško ime',
    'department'                => 'Oddelek',
    'location'                  => 'Lokacija',
    'asset_tag'                 => 'Oznaka sredstva',
    'asset_name'                => 'Ime',
    'asset_category'            => 'Kategorija',
    'asset_manufacturer'        => 'Proizvajalec',
    'asset_model'               => 'Model',
    'asset_serial'              => 'Serijska številka',
    'asset_location'            => 'Lokacija',
    'asset_checked_out'         => 'Izdano',
    'asset_expected_checkin'    => 'Predviden datum dobave',
    'date'                      => 'Datum:',
    'phone'                     => 'Telefonska št. Lokacije',
    'signed_by_asset_auditor'   => 'Podpisal/a Je (revizor sredstva):',
    'signed_by_finance_auditor' => 'Podpisal/a Je (finančni revizor):',
    'signed_by_location_manager' => 'Podpisal/a Je (lokacijski menedžer):',
    'signed_by'                 => 'Odpisal/a Je:',
];
